@@ -33,11 +33,6 @@
 #include <KLocalizedString>
 #include "kleopatra_debug.h"
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
-# define GPGME_HAS_REMARKS
-#endif
-
 using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace GpgME;
@@ -151,16 +146,15 @@ void CertifyCertificateCommand::doStart()
         return;
     }
 
-    std::vector<Key> secKeys;
-    Q_FOREACH (const Key &secKey, KeyCache::instance()->secretKeys()) {
-        // Only include usable keys.
-        if (secKey.canCertify() && secKey.protocol() == OpenPGP && !secKey.isRevoked() &&
-            !secKey.isExpired() && !secKey.isInvalid()) {
-            secKeys.push_back(secKey);
-        }
-    }
+    auto findAnyGoodKey = []() {
+        const std::vector<Key> secKeys = KeyCache::instance()->secretKeys();
+        return std::any_of(secKeys.cbegin(), secKeys.cend(), [](const Key &secKey) {
+            return secKey.canCertify() && secKey.protocol() == OpenPGP && !secKey.isRevoked()
+                   && !secKey.isExpired() && !secKey.isInvalid();
+        });
+    };
 
-    if (secKeys.empty()) {
+    if (!findAnyGoodKey()) {
         auto sel = KMessageBox::questionYesNo(d->parentWidgetOrView(),
                     xi18nc("@info", "To certify other certificates, you first need to create an OpenPGP certificate for yourself.") +
                     QStringLiteral("<br><br>") +
@@ -171,7 +165,7 @@ void CertifyCertificateCommand::doStart()
             auto cmd = new Commands::NewCertificateCommand();
             cmd->setParentWidget(d->parentWidgetOrView());
             cmd->setProtocol(GpgME::OpenPGP);
-            loop.connect(cmd, SIGNAL(finished()), SLOT(quit()));
+            connect(cmd, &Command::finished, &loop, &QEventLoop::quit);
             QMetaObject::invokeMethod(cmd, &Commands::NewCertificateCommand::start, Qt::QueuedConnection);
             loop.exec();
         } else {
@@ -179,38 +173,33 @@ void CertifyCertificateCommand::doStart()
             d->finished();
             return;
         }
-        Q_FOREACH (const Key &secKey, KeyCache::instance()->secretKeys()) {
-            // Check again for secret keys
-            if (secKey.canCertify() && secKey.protocol() == OpenPGP && !secKey.isRevoked() &&
-                !secKey.isExpired() && !secKey.isInvalid()) {
-                secKeys.push_back(secKey);
-            }
-        }
-        if (secKeys.empty()) {
+
+        // Check again for secret keys
+        if (!findAnyGoodKey()) {
             qCDebug(KLEOPATRA_LOG) << "Sec Keys still empty after keygen.";
             Q_EMIT(canceled());
             d->finished();
             return;
         }
     }
-    const Key &key = keys.front();
 
-    for (const UserID &uid : std::as_const(d->uids))
-        if (qstricmp(uid.parent().primaryFingerprint(), key.primaryFingerprint()) != 0) {
-            qCWarning(KLEOPATRA_LOG) << "User-ID <-> Key mismatch!";
-            d->finished();
-            return;
-        }
+    const char *primary = keys.front().primaryFingerprint();
+    const bool anyMismatch = std::any_of(d->uids.cbegin(), d->uids.cend(), [primary](const UserID &uid) {
+        return qstricmp(uid.parent().primaryFingerprint(), primary) != 0;
+    });
+    if (anyMismatch) {
+        qCWarning(KLEOPATRA_LOG) << "User ID <-> Key mismatch!";
+        d->finished();
+        return;
+    }
 
     d->ensureDialogCreated();
     Q_ASSERT(d->dialog);
 
     Key target = d->key();
-#ifdef GPGME_HAS_REMARKS
     if (!(target.keyListMode() & GpgME::SignatureNotations)) {
         target.update();
     }
-#endif
     d->dialog->setCertificateToCertify(target);
     if (d->uids.size()) {
         d->dialog->setSelectedUserIDs(d->uids);
@@ -257,25 +246,18 @@ void CertifyCertificateCommand::Private::slotCertificationPrepared()
     job->setUserIDsToSign(dialog->selectedUserIDs());
     job->setSigningKey(dialog->selectedSecretKey());
     job->setCheckLevel(dialog->selectedCheckLevel());
-#ifdef GPGME_HAS_REMARKS
     if (!dialog->tags().isEmpty()) {
         // do not set an empty remark to avoid an empty signature notation (GnuPG bug T5142)
         job->setRemark(dialog->tags());
     }
-    // This also came with 1.14.0
     job->setDupeOk(true);
-#endif
-#ifdef QGPGME_SUPPORTS_TRUST_SIGNATURES
     if (dialog->trustSignatureSelected() && !dialog->trustSignatureDomain().isEmpty()) {
         // always create level 1 trust signatures with complete trust
         job->setTrustSignature(TrustSignatureTrust::Complete, 1, dialog->trustSignatureDomain());
     }
-#endif
-#ifdef QGPGME_SUPPORTS_SIGNATURE_EXPIRATION
     if (!dialog->expirationDate().isNull()) {
         job->setExpirationDate(dialog->expirationDate());
     }
-#endif
 
     if (const Error err = job->start(key())) {
         slotResult(err);
@@ -299,8 +281,8 @@ void CertifyCertificateCommand::Private::ensureDialogCreated()
     dialog = new CertifyCertificateDialog;
     applyWindowID(dialog);
 
-    connect(dialog, SIGNAL(rejected()), q, SLOT(slotDialogRejected()));
-    connect(dialog, SIGNAL(accepted()), q, SLOT(slotCertificationPrepared()));
+    connect(dialog, &QDialog::rejected, q, [this]() { slotDialogRejected(); });
+    connect(dialog, &QDialog::accepted, q, [this]() { slotCertificationPrepared(); });
 }
 
 void CertifyCertificateCommand::Private::createJob()
@@ -320,8 +302,7 @@ void CertifyCertificateCommand::Private::createJob()
 
     connect(j, &Job::progress,
             q, &Command::progress);
-    connect(j, SIGNAL(result(GpgME::Error)),
-            q, SLOT(slotResult(GpgME::Error)));
+    connect(j, &SignKeyJob::result, q, [this](const GpgME::Error &result) { slotResult(result); });
 
     job = j;
 }
