@@ -3,6 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2022 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,11 +14,14 @@
 #include "newcertificatecommand.h"
 
 #include "command_p.h"
+#include "newopenpgpcertificatecommand.h"
+
+#include "dialogs/choosecertificateprotocoldialog.h"
+#include "newcertificatewizard/newcertificatewizard.h"
 
 #include <settings.h>
 
-#include <newcertificatewizard/newcertificatewizard.h>
-
+#include <kleopatra_debug.h>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
@@ -30,20 +35,25 @@ class NewCertificateCommand::Private : public Command::Private
         return static_cast<NewCertificateCommand *>(q);
     }
 public:
-    explicit Private(NewCertificateCommand *qq, KeyListController *c);
-    ~Private() override;
+    explicit Private(NewCertificateCommand *qq, KeyListController *c)
+        : Command::Private{qq, c}
+    {
+    }
 
-    void init();
+    void chooseProtocol();
+    void createCertificate();
 
 private:
-    void slotDialogRejected();
+    void onProtocolChosen();
+
     void slotDialogAccepted();
 
 private:
     void ensureDialogCreated();
 
 private:
-    Protocol protocol;
+    Protocol protocol = GpgME::UnknownProtocol;
+    QPointer<ChooseCertificateProtocolDialog> protocolDialog;
     QPointer<NewCertificateWizard> dialog;
 };
 
@@ -59,79 +69,64 @@ const NewCertificateCommand::Private *NewCertificateCommand::d_func() const
 #define d d_func()
 #define q q_func()
 
-NewCertificateCommand::Private::Private(NewCertificateCommand *qq, KeyListController *c)
-    : Command::Private(qq, c),
-      protocol(UnknownProtocol),
-      dialog()
+void NewCertificateCommand::Private::chooseProtocol()
 {
+    Q_ASSERT(protocol == GpgME::UnknownProtocol);
+    Q_ASSERT(!protocolDialog);
 
+    protocolDialog = new ChooseCertificateProtocolDialog;
+    applyWindowID(protocolDialog);
+
+    connect(protocolDialog, &QDialog::accepted, q, [this]() {
+        onProtocolChosen();
+    });
+    connect(protocolDialog, &QDialog::rejected, q, [this]() {
+        canceled();
+        protocolDialog->deleteLater();
+    });
+
+    protocolDialog->show();
 }
 
-NewCertificateCommand::Private::~Private() {}
-
-NewCertificateCommand::NewCertificateCommand()
-    : Command(new Private(this, nullptr))
+void NewCertificateCommand::Private::onProtocolChosen()
 {
-    d->init();
-}
+    protocol = protocolDialog->protocol();
+    protocolDialog->deleteLater();
 
-NewCertificateCommand::NewCertificateCommand(KeyListController *c)
-    : Command(new Private(this, c))
-{
-    d->init();
-}
-
-NewCertificateCommand::NewCertificateCommand(QAbstractItemView *v, KeyListController *c)
-    : Command(v, new Private(this, c))
-{
-    d->init();
-}
-
-void NewCertificateCommand::Private::init()
-{
-
-}
-
-NewCertificateCommand::~NewCertificateCommand() {}
-
-void NewCertificateCommand::setProtocol(Protocol proto)
-{
-    d->protocol = proto;
-    if (d->dialog) {
-        d->dialog->setProtocol(proto);
-    }
-}
-
-Protocol NewCertificateCommand::protocol() const
-{
-    if (d->dialog) {
-        return d->dialog->protocol();
+    if (protocol == GpgME::OpenPGP) {
+        auto cmd = new NewOpenPGPCertificateCommand{view(), controller()};
+        if (parentWidgetOrView() != view()) {
+            cmd->setParentWidget(parentWidgetOrView());
+        }
+        cmd->setParentWId(parentWId());
+        connect(cmd, &NewOpenPGPCertificateCommand::finished,
+                q, [this]() { finished(); });
+        connect(cmd, &NewOpenPGPCertificateCommand::canceled,
+                q, [this]() { canceled(); });
+        cmd->start();
     } else {
-        return d->protocol;
+        createCertificate();
     }
 }
 
-void NewCertificateCommand::doStart()
+void Kleo::Commands::NewCertificateCommand::Private::createCertificate()
 {
-    d->ensureDialogCreated();
-    Q_ASSERT(d->dialog);
+    Q_ASSERT(protocol != GpgME::UnknownProtocol);
+    Q_ASSERT(!dialog);
 
-    const Kleo::Settings settings{};
-    const auto cmsAllowed = settings.cmsEnabled() && settings.cmsCertificateCreationAllowed();
-    if (d->protocol == UnknownProtocol && !cmsAllowed) {
-        d->protocol = GpgME::OpenPGP;
-    }
-    if (d->protocol != UnknownProtocol) {
-        d->dialog->setProtocol(d->protocol);
-    }
+    dialog = new NewCertificateWizard;
+    applyWindowID(dialog);
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
 
-    d->dialog->show();
-}
+    connect(dialog, &QDialog::accepted, q, [this]() {
+        slotDialogAccepted();
+    });
+    connect(dialog, &QDialog::rejected, q, [this]() {
+        canceled();
+    });
 
-void NewCertificateCommand::Private::slotDialogRejected()
-{
-    Q_EMIT q->canceled();
-    finished();
+    dialog->setProtocol(protocol);
+    dialog->show();
 }
 
 void NewCertificateCommand::Private::slotDialogAccepted()
@@ -139,6 +134,48 @@ void NewCertificateCommand::Private::slotDialogAccepted()
     finished();
 }
 
+NewCertificateCommand::NewCertificateCommand()
+    : Command(new Private(this, nullptr))
+{
+}
+
+NewCertificateCommand::NewCertificateCommand(KeyListController *c)
+    : Command(new Private(this, c))
+{
+}
+
+NewCertificateCommand::NewCertificateCommand(QAbstractItemView *v, KeyListController *c)
+    : Command(v, new Private(this, c))
+{
+}
+
+NewCertificateCommand::~NewCertificateCommand() = default;
+
+void NewCertificateCommand::setProtocol(Protocol proto)
+{
+    d->protocol = proto;
+}
+
+Protocol NewCertificateCommand::protocol() const
+{
+    return d->protocol;
+}
+
+void NewCertificateCommand::doStart()
+{
+    const Kleo::Settings settings{};
+    const auto cmsAllowed = settings.cmsEnabled() && settings.cmsCertificateCreationAllowed();
+    if (d->protocol == UnknownProtocol && !cmsAllowed) {
+        d->protocol = GpgME::OpenPGP;
+    }
+
+    if (d->protocol == UnknownProtocol) {
+        d->chooseProtocol();
+    } else {
+        d->createCertificate();
+    }
+}
+
 void NewCertificateCommand::doCancel()
 {
     if (d->dialog) {
@@ -146,20 +183,6 @@ void NewCertificateCommand::doCancel()
     }
 }
 
-void NewCertificateCommand::Private::ensureDialogCreated()
-{
-    if (dialog) {
-        return;
-    }
-
-    dialog = new NewCertificateWizard;
-    applyWindowID(dialog);
-    dialog->setAttribute(Qt::WA_DeleteOnClose);
-
-    connect(dialog, SIGNAL(rejected()), q, SLOT(slotDialogRejected()));
-    connect(dialog, SIGNAL(accepted()), q, SLOT(slotDialogAccepted()));
-}
-
 #undef d
 #undef q
 
