@@ -18,8 +18,7 @@
 
 #include "accessibility/accessiblewidgetfactory.h"
 
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 #endif
 
@@ -99,8 +98,10 @@ static void fillKeyCache(Kleo::UiServer *server)
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     KleopatraApplication app(argc, argv);
     KCrash::initialize();
     QAccessible::installFactory(Kleo::accessibleWidgetFactory);
@@ -110,6 +111,9 @@ int main(int argc, char **argv)
 
     KLocalizedString::setApplicationDomain("kleopatra");
 
+    AboutData aboutData;
+    KAboutData::setApplicationData(aboutData);
+
     if (Kleo::userIsElevated()) {
         /* This is a safeguard against bugreports that something fails because
          * of permission problems on windows.  Some users still have the Windows
@@ -147,17 +151,13 @@ int main(int argc, char **argv)
     app.init();
     qCDebug(KLEOPATRA_LOG) << "Startup timing:" << timer.elapsed() << "ms elapsed: Application initialized";
 
-    AboutData aboutData;
-
-    KAboutData::setApplicationData(aboutData);
-
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     kleopatra_options(&parser);
 
     parser.process(QApplication::arguments());
     aboutData.processCommandLine(&parser);
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kleopatra"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kleopatrarc")
                                          << QStringLiteral("libkleopatrarc"));
