@@ -82,10 +82,7 @@ namespace
 class TemporaryFile : public QTemporaryFile
 {
 public:
-    explicit TemporaryFile() : QTemporaryFile() {}
-    explicit TemporaryFile(const QString &templateName) : QTemporaryFile(templateName) {}
-    explicit TemporaryFile(QObject *parent) : QTemporaryFile(parent) {}
-    explicit TemporaryFile(const QString &templateName, QObject *parent) : QTemporaryFile(templateName, parent) {}
+    using QTemporaryFile::QTemporaryFile;
 
     void close() override {
         if (isOpen())
@@ -368,7 +365,7 @@ class FileOutput : public OutputImplBase
 {
 public:
     explicit FileOutput(const QString &fileName, const std::shared_ptr<OverwritePolicy> &policy);
-    ~FileOutput()
+    ~FileOutput() override
     {
         qCDebug(KLEOPATRA_LOG) << this;
     }
@@ -385,7 +382,7 @@ public:
     void doCancel() override {
         qCDebug(KLEOPATRA_LOG) << this;
     }
-    QString fileName() const
+    QString fileName() const override
     {
         return m_fileName;
     }
@@ -574,8 +571,8 @@ void FileOutput::doFinalize()
          * rename and remove. So if we can't find our temporary file we try
          * to workaround that bug. */
         qCDebug(KLEOPATRA_LOG) << "failure to find " << tmpFileName;
-        if (tmpFileName.startsWith(QStringLiteral("UNC"))) {
-            tmpFileName.replace(QRegExp(QStringLiteral("^UNC")), QStringLiteral("/"));
+        if (tmpFileName.startsWith(QLatin1String("UNC"))) {
+            tmpFileName.replace(0, strlen("UNC"), QLatin1Char('/'));
             qtbug83365_workaround = true;
         }
         const QFileInfo fi2(tmpFileName);
